searchData={"items":[{"type":"module","title":"Diffie","doc":"Diffie is a module for making human-readable reports of\nthe differences between two strings,\nor between two lists of objects (of whatever type).\n\nNOT FOR DIFFIE-HELLMAN KEY EXCHANGE!","ref":"Diffie.html"},{"type":"function","title":"Diffie.diff_report/3","doc":"`diff_report(old, new, opts \\\\ [])`\n\n`diff_report` returns a string\ncontaining a report (hence the name),\nsimilar to a simplified version of the `diff` command-line utility,\nof the differences between the two strings, or two lists.\n\nGiven two strings, by default it works line by line,\nand is case-sensitive,\nbut you can change this with options, as follows:\n\n- `:ignore_case` - (boolean) be case-insensitive when comparing the strings.  Does not get applied to strings _within objects_.  If you want that, you will have to use a custom transformation function (see below).  Also applicable to the version that takes two lists, _if_ you pass it two lists _of strings_.\n\n- `omit_deletes` - (boolean) omit deleted items, and old versions of changed items.  Also applicable to the version that takes two lists.\n\n- `split_on` - (string or regex) split strings on this, not \\n.\n\n- `transform` - (function reference) function to apply to items in the report.  Also applicable to the version that takes two lists.\n\nIf you do _not_ supply a transformation:\n- strings will be handled as-is,\n- items that implement the `String.chars` protocol will be sent to `to_string`,\n- and anything else will be sent to `inspect`.\n\nIf your list items do not implement `String.chars`\nand you wish to apply some transformation,\nthat transformation must include turning them into\nsomething that does, such as piping through `inspect`.","ref":"Diffie.html#diff_report/3"},{"type":"function","title":"Examples: - Diffie.diff_report/3","doc":"```\niex> Diffie.diff_report(\"foo\\nbar\", \"foo\\nbar\\nbaz\")\n\"Added:\\n> baz\"\n\niex> Diffie.diff_report(\"foo\\nbar\\nbaz\", \"foo\\nbaz\")\n\"Removed:\\n  Diffie.diff_report(\"foo\\nbar\\nbaz\", \"foo\\nboo\\nbaz\")\n\"Changed:\\n  boo\"\n\niex> Diffie.diff_report(\"fooXXbarXXbaz\", \"fooXXbaz\", split_on: \"XX\")\n\"Removed:\\n  Diffie.diff_report(\"bar\", \"baz\", split_on: \"\")\n\"Changed:\\n  z\"\n\niex> Diffie.diff_report(\"foo\\nbar\\nbaz\", \"foo\\nboo\\nbaz\", omit_deletes: true)\n\"Into:\\n> boo\"  # note removal of \"Changed:\\n  Diffie.diff_report(\"foo bar\\nbaz quux\", \"fox bear\\nbaz quix\",\n...>                    split_on: ~r{\\s})\n\"Changed:\\n  fox\\n> bear\\n\\nChanged:\\n  quix\"\n\niex> Diffie.diff_report(\"foo\\nbar\\nbaz\", \"foo\\nbaz\", transform: &String.upcase/1)\n\"Removed:\\n  Diffie.diff_report(\"The quick brown fox jumps\\nover the lazy dog.\",\n...>                    \"That fox\\njumps quickly over\\nthe dig!\",\n...>                    split_on: ~r/\\s/, transform: &String.upcase/1)\n\"Changed:\\n  THAT\\n\\nAdded:\\n> QUICKLY\\n\\nChanged:\\n  DIG!\"\n\niex> Diffie.diff_report(\"The quick brown fox jumps over the lazy dog.\",\n...>                    \"That fox jumps quickly over the dig!\",\n...>                    split_on: ~r/\\s/, omit_deletes: true)\n\"Into:\\n> That\\n\\nAdded:\\n> quickly\\n\\nInto:\\n> dig!\"\n\niex> Diffie.diff_report([1,2], [1,2,3])\n\"Added:\\n> 3\"\n\niex> Diffie.diff_report([1,2,3], [1,2])\n\"Removed:\\n< 3\"\n\niex> Diffie.diff_report([1,2,3], [1,2,5])\n\"Changed:\\n< 3\\n\\nInto:\\n> 5\"\n\niex> Diffie.diff_report([1,2,3], [1,2,5], omit_deletes: true)\n\"Into:\\n> 5\"  # note removal of \"Changed:\\n< 3\\n\\n\"\n\niex> Diffie.diff_report([1,2], [1,2,3], transform: fn x->x*2 end)\n\"Added:\\n> 6\"\n\niex> alice = %{name: \"Alice\", age: \"29\"}\niex> bob = %{name: \"Bob\", age: \"52\"}\niex> Diffie.diff_report([alice], [alice,bob])\n\"Added:\\n> %{name: \\\"Bob\\\", age: \\\"52\\\"}\"\n\niex> alice = %{name: \"Alice\", age: \"29\"}\niex> bob = %{name: \"Bob\", age: \"52\"}\niex> Diffie.diff_report([alice], [alice, bob],\n...>                    transform: fn p -> Map.delete(p, :age) end)\n** (Protocol.UndefinedError) protocol String.Chars not implemented for %{name: \"Bob\"} of type Map. This protocol is implemented for the following type(s): Atom, BitString, Date, DateTime, Float, Integer, List, NaiveDateTime, Time, URI, Version, Version.Requirement\n\niex> alice = %{name: \"Alice\", age: \"29\"}\niex> bob = %{name: \"Bob\", age: \"52\"}\niex> Diffie.diff_report([alice], [alice, bob],\n...>                    transform: fn p -> Map.delete(p, :age) |> inspect end)\n\"Added:\\n> %{name: \\\"Bob\\\"}\"\n\niex> alice = %{name: \"Alice\", age: \"29\"}\niex> bob = %{name: \"Bob\", age: \"52\"}\niex> Diffie.diff_report([alice], [alice, bob],\n...>                    transform: fn p -> p.name end)\n\"Added:\\n> Bob\"\n```","ref":"Diffie.html#diff_report/3-examples"},{"type":"extras","title":"Diffie","doc":"# Diffie\n\nDiffie is a library for making textual reports,\nsimilar to a simplified version of the `diff` command-line utility,\nof the differences between two strings, or two lists of objects.\n\nNOT FOR DIFFIE-HELLMAN KEY EXCHANGE!","ref":"readme.html"},{"type":"extras","title":"Installation - Diffie","doc":"The package can be installed\nby adding `diffie` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:diffie, \"~> 0.1.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"License - Diffie","doc":"3-Clause BSD; see LICENSE file.","ref":"readme.html#license"}],"content_type":"text/markdown"}